==> jakarta-persistence-tck-2.2.0.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/annotations/orderby/Insurance.java <==
/*
 * Copyright (c) 2007, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.jpa.core.annotations.orderby;

import javax.persistence.*;
import java.util.List;

/*
 * Insurance
 */

@Entity
public class Insurance implements java.io.Serializable {

  // Instance variables
  private int id;

  private String carrier;

  private List<Employee> employees;

  public Insurance() {
  }

  public Insurance(int id, String carrier) {
    this.id = id;
    this.carrier = carrier;
  }

  // ===========================================================
  // getters and setters for the state fields

  @Id
  @Column(name = "INSID")
  public int getId() {
    return id;
  }

  public void setId(int id) {
    this.id = id;
  }

  public String getCarrier() {
    return carrier;
  }

  public void setCarrier(String carrier) {
    this.carrier = carrier;
  }

  // ===========================================================
  // getters and setters for the association fields

  @OneToMany(mappedBy = "insurance")
  @OrderBy("firstName DESC")
  public List<Employee> getEmployees() {
    return employees;
  }

  public void setEmployees(List<Employee> employees) {
    this.employees = employees;
  }

}

==> jakarta-persistence-tck-3.1.0.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/annotations/orderby/Insurance.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.jpa.core.annotations.orderby;

import java.util.List;

import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.OneToMany;
import jakarta.persistence.OrderBy;

/*
 * Insurance
 */

@Entity
public class Insurance implements java.io.Serializable {

  // Instance variables
  private int id;

  private String carrier;

  private List<Employee> employees;

  public Insurance() {
  }

  public Insurance(int id, String carrier) {
    this.id = id;
    this.carrier = carrier;
  }

  // ===========================================================
  // getters and setters for the state fields

  @Id
  @Column(name = "INSID")
  public int getId() {
    return id;
  }

  public void setId(int id) {
    this.id = id;
  }

  public String getCarrier() {
    return carrier;
  }

  public void setCarrier(String carrier) {
    this.carrier = carrier;
  }

  // ===========================================================
  // getters and setters for the association fields

  @OneToMany(mappedBy = "insurance")
  @OrderBy("firstName DESC")
  public List<Employee> getEmployees() {
    return employees;
  }

  public void setEmployees(List<Employee> employees) {
    this.employees = employees;
  }

}
